<?php
/**
* Plugin Name: Knjižnice: Vtičnik knjige
* Plugin URI: https://www.knjiznice.si
* Description: Urejanje in prikazovanje knjig na spletni strani.
* Version: 1.1.6
* Author: TrueCAD d.o.o.
* Author URI: https://www.truecad.si/
**/

add_action( 'init', 'init_knjige' );
function init_knjige() {
	// Check if Elementor installed and activated
	if ( ! did_action( 'elementor/loaded' ) ) {
		//add_action( 'admin_notices', array( $this, 'admin_notice_missing_main_plugin' ) );
		return;
	}
	add_action( 'elementor/widgets/widgets_registered','register_knjige_widgets');
	//require_once( 'plugin.php' );
}

function register_knjige_widgets() {
	require_once( __DIR__ . '/widgets/knjige-slider.php' );
	// Register Widgets
	\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Knjige_Slider() );
}

/** CUSTOM TYPE */
function knjiznice_register_posttype_knjige() {

	$labels = array(
		'name' => __('Zvrsti knjig', 'knjiznice'),
		'singular_name' => __('Zvrst', 'knjiznice'),
		'search_items' =>  __( 'Išči zvrst', 'knjiznice'),
		'all_items' => __( 'Vse zvrsti', 'knjiznice'),
		'parent_item' => __( 'Nadrejena zvrst', 'knjiznice'),
		'parent_item_colon' => __( 'Nadrejena zvrst:', 'knjiznice'),
		'edit_item' => __( 'Uredi zvrst', 'knjiznice'),
		'update_item' => __( 'Posodobi zvrst', 'knjiznice'),
		'add_new_item' => __( 'Dodaj novo', 'knjiznice'),
		'new_item_name' => __( 'Novo ime', 'knjiznice'),
		'menu_name' => __( 'Zvrsti', 'knjiznice'),
		'not_found' => __( 'Ni najdenih zvrsti.', 'knjiznice'),
	);

	register_taxonomy('zvrsti-knjig', array('knjige'), array(
		'hierarchical' => true,
		'labels' => $labels,
		'show_ui' => true,
		'show_admin_column' => true,
		'query_var' => true,
		'rewrite' => array( 'slug' => 'zvrst-knjige' )
	));

	$supports = array(
		'title', // post title
		'editor', // post content
		'author', // post author
		'thumbnail', // featured images
		'revisions', // post revisions
		'post-formats' // post formats
	);

	$labels = array(
		'name' => __('Knjige', 'knjiznice'),
        'singular_name' => __('Knjiga', 'knjiznice'),
		'menu_name' => __('Knjige', 'knjiznice'),
		'name_admin_bar' => __('Knjige', 'knjiznice'),
		'add_new' => __('Dodaj novo', 'knjiznice'),
		'add_new_item' => __('Dodaj novo knjigo', 'knjiznice'),
		'new_item' => __('Nova knjiga', 'knjiznice'),
		'edit_item' => __('Uredi knjigo', 'knjiznice'),
		'view_item' => __('Poglej knjigo', 'knjiznice'),
		'all_items' => __('Vse knjige', 'knjiznice'),
		'search_items' => __('Iskanje knjig', 'knjiznice'),
		'not_found' => __('Ni knjig.', 'knjiznice')
	);

    register_post_type( 'knjige',
        array(
			'supports' => $supports,
            'labels' => $labels,
            'public' => true,
            'has_archive' => true,
			'taxonomies' 	      => array('zvrsti-knjig'),
            'rewrite' => array('slug' => 'knjige'),
        )
    );
}
add_action( 'init', 'knjiznice_register_posttype_knjige' );

function knjiznice_knjige_parent_active_menu($menu) {
    global $post;
    if (get_post_type($post) == 'knjige') {
        $menu = str_replace( 'menu-item-object-knjige', 'current-menu-parent', $menu);
    }
    return $menu;
}
add_filter( 'nav_menu_css_class', 'knjiznice_knjige_parent_active_menu', 10,2 );

function knjiznice_knjige_add_admin_scripts($hook) {
    global $post;
    if ( $hook == 'post-new.php' || $hook == 'post.php' ) {
        if ( 'knjige' === $post->post_type ) {
            wp_enqueue_script('custom-type-knjige-scriptjs', plugin_dir_url(__FILE__).'js/script.js', array(), '1.1.4' );
        }
    }
}
add_action( 'admin_enqueue_scripts', 'knjiznice_knjige_add_admin_scripts', 10, 2 );

class knjiznice_widget_zvrstiknjig extends WP_Widget {
	function __construct() {
		parent::__construct('knjiznice_widget_zvrstiknjig', __('Zvrsti knjig', 'knjiznice'), array( 'description' => __( 'Zvrsti knjig', 'knjiznice' )));
	}
	
	public function widget($args, $instance) {
		$title = apply_filters('widget_title', $instance['title']);
		echo $args['before_widget'];
		if ( ! empty( $title ) )
		echo $args['before_title'] . $title . $args['after_title'];
		$categories_knjige = get_terms(array('taxonomy' => 'zvrsti-knjig','hide_empty' => false)); 
		$current_obj = get_queried_object();
		$term_id = -1;
		if ($current_obj instanceof WP_Term) $term_id = $current_obj->term_id;
		?>
		<ul>
			<?php foreach ($categories_knjige as $category_knjige) : ?>
			<li class="<?php echo $term_id == $category_knjige->term_id ? 'current':''; ?>"><a href="<?php echo get_term_link($category_knjige); ?>"><?php echo $category_knjige->name; ?></a> (<?php echo $category_knjige->count; ?>)</li>
			<?php endforeach; ?>
		</ul>
		<?php
		echo $args['after_widget'];
	}
	
	public function form($instance) {
		$title = '';
		if (isset($instance['title'])) $title = $instance['title'];
		else $title = __('', 'knjiznice');
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>
		<?php 
	}
	
	public function update($new_instance, $old_instance) {
		$instance = array();
		$instance['title'] = (!empty($new_instance['title'])) ? strip_tags($new_instance['title']) : '';
		return $instance;
	}
}

function knjiznice_register_widgets_knjige() {
	 register_widget('knjiznice_widget_zvrstiknjig');
}
add_action('widgets_init', 'knjiznice_register_widgets_knjige');

function knjiznice_limit_posttype_knjige($query) {
   if ($query->is_main_query() && $query->is_post_type_archive('knjige') && !is_admin()) {
		$query->set('date_query',
			array(
				'column' => 'post_date',
				'after' => '-90 days'
			)
		);
   }
}
add_action( 'pre_get_posts', 'knjiznice_limit_posttype_knjige' );